@@ -64,6 +64,8 @@ __all__ = [
     "reset_logger_width",
     "display",
     "typedispatch",
+    "deepcopy",
+    "batchify"
 ]
 
 from .logger import *
@@ -72,6 +74,8 @@ from fastcore.foundation import L
 from fastcore.dispatch import typedispatch
 
 import glob, numpy as np, pandas as pd, tqdm, os, sys, re
+from copy import deepcopy
+from typing import Union, List, Tuple
 from IPython.display import display
 import PIL
 from PIL import Image
@@ -549,7 +553,7 @@ class BB:
         x, y, X, Y = self
         return BB(x + a, y + b, X + a, Y + b)
 
-    def remap(self, og_dim: ("h", "w"), new_dim: ("H", "W")):
+    def remap(self, og_dim: Tuple[int, int], new_dim: Tuple[int, int]):
         h, w = og_dim
         H, W = new_dim
         sf_x = H / h
@@ -561,11 +565,11 @@ class BB:
             round(sf_y * self.Y),
         )
 
-    def relative(self, dim: ("h", "w")):
+    def relative(self, dim: Tuple[int, int]):
         h, w = dim
         return BB(self.x / w, self.y / h, self.X / w, self.Y / h)
 
-    def absolute(self, dim: ("h", "w")):
+    def absolute(self, dim: Tuple[int, int]):
         h, w = dim
         return BB(self.x * w, self.y * h, self.X * w, self.Y * h)
 
@@ -699,7 +703,7 @@ def set_logging_level(level):
     logger.add(sys.stderr, level=level)
 
 
-def resize_old(im: np.ndarray, sz: [float, ("H", "W")]):
+def resize_old(im: np.ndarray, sz: Union[float, Tuple[int, int]]):
     h, w = im.shape[:2]
     if isinstance(sz, float):
         frac = sz
@@ -720,7 +724,7 @@ def resize_old(im: np.ndarray, sz: [float, ("H", "W")]):
     return cv2.resize(im, (W, H))
 
 
-def resize(im: np.ndarray, sz: [float, ("H", "W"), (str, ("H", "W"))]):
+def resize(im: np.ndarray, sz: Union[float, Tuple[int, int], Tuple[str, Tuple[int, int]]]):
     """Resize an image based on info from sz
     *Aspect ratio is preserved
     Examples:
@@ -908,3 +912,26 @@ def shrink_bbs(bbs, eps=0.2):
         BB(x + (w * epsx), y + (h * epsy), X - (w * epsX), Y - (h * epsY))
         for (x, y, X, Y), (h, w) in zip(bbs, shs)
     ]
+
+def batchify(n, bs):
+    n = deepcopy(n)
+    l = []
+    if isinstance(n, int):
+        remaining = n
+    else:
+        remaining = len(n)
+    while remaining > bs:
+        if isinstance(n, int):
+            l.append(bs)
+        else:
+            l.append(
+                n[:bs]
+            )
+            del n[:bs]
+        remaining -= bs
+    if isinstance(n, int):
+        l.append(remaining)
+    else:
+        l.append(n[:remaining])
+    return l
+    
\ No newline at end of file
